/*----------------------------------------------------------------------------+
| Library Name: GETDTTM.PLB                                                   |
|                                                                             |
| Description:  Contains two functions GETFDATE & GETFTIME                    |
|                                                                             |
|                                                                             |
|     Function: GETFDATE                                                      |
|    -------------------                                                      |
|                                                                             |
|      Purpose: Gets a file(s) date(s)                                        |
|                                                                             |
|       Syntax: GETFDATE(<expC>)                                              |
|                                                                             |
|   Input                                                                     |
|   Parameters: <expC> - the name of the file whose date we want to get.      |
|                                                                             |
|   Output                                                                    |
|   Parameters: <expC> - returns the files date in the character string       |
|                        format mm/dd/yyyy. If the call fails for any reason  |
|                        it returns the character string "  /  /    ".        |
|                                                                             |
|    Example 1: GETFDATE("TEST.PRG")                                          |       |
|               - gets the date on the file TEST.PRG in the current           |
|                 directory.                                                  |
|                                                                             |
|                                                                             |
|   Misc Notes: The file name can contain a drive and path. <expC> can be     |
|               either upper or lower case.                                   |
|                                                                             |
|                                                                             |
|                                                                             |
|                                                                             |
|     Function: GETFTIME                                                      |
|    -------------------                                                      |
|                                                                             |
|      Purpose: Gets a file(s) time(s)                                        |
|                                                                             |
|       Syntax: GETFTIME(<expC>)                                              |
|                                                                             |
|   Input                                                                     |
|   Parameters: <expC> - the name of the file whose time we want to get.      |
|                                                                             |
|   Output                                                                    |
|   Parameters: <expC> - returns the files time in the character string       |
|                        format HH:MM:SS. If the call fails for any reason    |
|                        it returns the character string "  :  :  ".          |
|                                                                             |
|    Example 1: GETFTIME("TEST.PRG")                                          |       |
|               - gets the time on the file TEST.PRG in the current           |
|                 directory.                                                  |
|                                                                             |
|                                                                             |
|   Misc Notes: The file name can contain a drive and path. <expC> can be     |
|               either upper or lower case.                                   |
+-----------------------------------------------------------------------------*/
#include <string.h>
#include <stdio.h>
#include <dos.h>
#include <fcntl.h>
#include "pro_ext.h"

#define YEAR(t)    (((t & 0xFE00) >> 9) + 1980)
#define MONTH(t)   ((t & 0x01E0) >> 5)
#define DAY(t)     (t & 0x001F)
#define HOUR(t)    ((t & 0xF800) >> 11)
#define MINUTE(t)  ((t & 0x07E0) >> 5)
#define SECOND(t)  ((t & 0x001F) << 1)


void FAR getfdate(ParamBlk FAR *parm)
{
    int handle,
        retcode;
    unsigned short date,
                   time;
    char FAR * filename;

    char filedate[12];

    _SetHandSize(parm->p[0].val.ev_handle, parm->p[0].val.ev_length+1);
    _HLock(parm->p[0].val.ev_handle);
    filename = _HandToPtr(parm->p[0].val.ev_handle);
    filename[parm->p[0].val.ev_length] = '\0';

    if ( _dos_open( filename, O_RDONLY, &handle) != 0 )
        strcpy(filedate,"  /  /    ");
    else {
        _dos_getftime( handle, &date, &time);
        sprintf(filedate,"%02d/%02d/%4d",MONTH(date),DAY(date),YEAR(date));
        _dos_close(handle);
    }

    _HUnLock(parm->p[0].val.ev_handle);
    _RetChar(filedate);
    return;
}


void FAR getftime(ParamBlk FAR *parm)
{
    int handle,
        retcode;
    unsigned short date,
                   time;
    char FAR * filename;

    char filetime[12];

    _SetHandSize(parm->p[0].val.ev_handle, parm->p[0].val.ev_length+1);
    _HLock(parm->p[0].val.ev_handle);
    filename = _HandToPtr(parm->p[0].val.ev_handle);
    filename[parm->p[0].val.ev_length] = '\0';

    if ( _dos_open( filename, O_RDONLY, &handle) != 0 )
        strcpy(filetime,"  :  :  ");
    else {
        _dos_getftime( handle, &date, &time);
        sprintf(filetime,"%02d:%02d:%02d",HOUR(time),MINUTE(time),SECOND(time));
        _dos_close(handle);
    }

    _HUnLock(parm->p[0].val.ev_handle);
    _RetChar(filetime);
    return;
}


FoxInfo myFoxInfo[] =
{
    {"GETFDATE", getfdate, 1, "C"},
    {"GETFTIME", getftime, 1, "C"}
};


FoxTable _FoxTable =
{
    (FoxTable FAR *)0, sizeof(myFoxInfo) / sizeof(FoxInfo), myFoxInfo
};
